import { handleCustomInsertColumn } from "./SampleComponent";

export const toolbarConfig = {
  ribbon: [
    {
      id: 'home',
      text: 'HOME',
      buttonGroups: [
        {
          label: 'Undo',
          thumbnailClass: 'ribbon-thumbnail-undoredo',
          commandGroup: {
            children: [
              {
                direction: 'vertical',
                commands: ['undo', 'redo'],
              },
              {
                direction: 'vertical',
                commands: ['undoList', 'redoList'],
              },
            ],
          },
        },
        {
          label: 'Clipboard',
          thumbnailClass: 'ribbon-thumbnail-clipboard',
          commandGroup: {
            children: [
              {
                command: 'pasteAll',
                type: 'dropdown',
                children: [
                  'pasteAll',
                  'pasteFormulas',
                  'pasteValues',
                  'pasteFormatting',
                  'pasteValuesAndFormatting',
                  'pasteFormulasAndFormatting',
                ],
              },
              {
                direction: 'vertical',
                commands: ['cut', 'copy', 'formatPainter'],
              },
            ],
          },
        },
        {
          label: 'Fonts',
          indicator: 'indicatorFonts',
          thumbnailClass: 'ribbon-thumbnail-fonts',
          commandGroup: {
            direction: 'vertical',
            children: [
              {
                commands: [
                  'fontFamily',
                  'fontSize',
                  'increaseFontsize',
                  'decreaseFontsize',
                ],
              },
              {
                children: [
                  'fontWeight',
                  'fontItalic',
                  'fontUnderline',
                  'fontDoubleUnderline',
                  'separator',
                  {
                    command: 'border',
                    type: 'dropdown',
                    children: [
                      'bottomBorder',
                      'topBorder',
                      'leftBorder',
                      'rightBorder',
                      'separator',
                      'noBorder',
                      'allBorder',
                      'outsideBorder',
                      'thickBoxBorder',
                      'separator',
                      'bottomDoubleBorder',
                      'thickBottomBorder',
                      'topBottomBorder',
                      'topThickBottomBorder',
                      'topDoubleBottomBorder',
                      'moreBorder',
                    ],
                  },
                  'separator',
                  'backColor',
                  'foreColor',
                ],
              },
            ],
          },
        },
        {
          label: 'Alignment',
          indicator: 'indicatorAlignment',
          thumbnailClass: 'ribbon-thumbnail-alignment',
          commandGroup: {
            children: [
              {
                direction: 'vertical',
                children: [
                  {
                    children: [
                      'topAlign',
                      'middleAlign',
                      'bottomAlign',
                      'separator',
                      {
                        command: 'orientationList',
                        type: 'dropdown',
                        children: [
                          'angleCounterclockwise',
                          'angleClockwise',
                          'verticalText',
                          'rotateTextUp',
                          'rotateTextDown',
                          'separator',
                          'formatCellAlignment',
                        ],
                      },
                    ],
                  },
                  {
                    commands: [
                      'leftAlign',
                      'centerAlign',
                      'rightAlign',
                      'separator',
                      'decreaseIndent',
                      'increaseIndent',
                    ],
                  },
                ],
              },
              {
                type: 'separator',
              },
              {
                direction: 'vertical',
                children: [
                  {
                    commands: ['wrapText'],
                  },
                  {
                    children: [
                      {
                        command: 'mergeCenter',
                        type: 'dropdown',
                        children: [
                          'mergeCenterButton',
                          'mergeAcross',
                          'mergeCells',
                          'unMergeCells',
                        ],
                      },
                    ],
                  },
                ],
              },
            ],
          },
        },
        {
          label: 'Numbers',
          indicator: 'indicatorNumbers',
          thumbnailClass: 'ribbon-thumbnail-numbers',
          commandGroup: {
            direction: 'vertical',
            children: [
              {
                command: 'ribbonNumberFormat',
                type: 'dropdown',
                children: [
                  'formatGeneral',
                  'numberFormat',
                  'currencyFormat',
                  'accountingFormat',
                  'shortDateFormat',
                  'longDateformat',
                  'timeFormat',
                  'percentageFormat',
                  'fractionFormat',
                  'scientificFormat',
                  'textFormat',
                  'separator',
                  'formatMore',
                ],
              },
              {
                commands: [
                  'formatPercentage',
                  'formatComma',
                  'separator',
                  'increaseDecimal',
                  'decreaseDecimal',
                ],
              },
            ],
          },
        },
      ],
      visibleWhen:
        '!TableSheetActive && !DataManagerActive && !ContainMultipleHeaderCells || IsInTableSheetDesignMode',
    },
    {
      id: 'insert',
      text: 'INSERT',
      buttonGroups: [
        // {
        //   label: 'Tables',
        //   thumbnailClass: 'ribbon-thumbnail-table',
        //   commandGroup: {
        //     commands: ['insertTable', 'insertPivotTable', 'insertTableSheet'],
        //   },
        // },
        {
          label: 'Illustrations',
          thumbnailClass: 'ribbon-thumbnail-illustration',
          commandGroup: {
            commands: ['insertPicture', 'insertShape'],
          },
        },
      ],
      visibleWhen: '!IsInTableSheetDesignMode',
    },
    {
      id: 'formulas',
      text: 'FORMULAS',
      buttonGroups: [
        {
          label: 'Functions',
          thumbnailClass: 'ribbon-button-insertfunction',
          commandGroup: {
            commands: ['insertFunction'],
          },
        },
        {
          label: 'Functions Library',
          thumbnailClass: 'ribbon-thumbnail-functions',
          commandGroup: {
            children: [
              {
                command: 'formulaAutoSum',
                type: 'dropdown',
                children: [
                  'editingAutoSum',
                  'average',
                  'countNumbers',
                  'max',
                  'min',
                ],
              },
              'formulaFinancial',
              'logicalFormula',
              'logicalFormulaAllowDynamicArray',
              'formulaText',
              'formulaDateTime',
              'formulaLookupReference',
              'formulaLookupReferenceAllowDynamicArray',
              'formulaMathTrig',
              'formulaMathTrigAllowDynamicArray',
              'moreFunctions',
            ],
          },
        },
        {
          label: 'Names',
          thumbnailClass: 'ribbon-thumbnail-names',
          commandGroup: {
            commands: ['nameManager'],
          },
        },
        {
          label: 'Formula Auditing',
          thumbnailClass: 'ribbon-thumbnail-formula-auditing',
          commandGroup: {
            commands: ['showFormulas'],
          },
        },
      ],
      visibleWhen:
        '!TableSheetActive && !DataManagerActive && !IsInTableSheetDesignMode',
    },
    {
      id: 'data',
      text: 'DATA',
      buttonGroups: [
        {
          label: 'Sort & Filter',
          thumbnailClass: 'ribbon-thumbnail-sortAndFilter',
          commandGroup: {
            children: [
              {
                direction: 'vertical',
                commands: ['sortAZData', 'sortZAData'],
              },
              {
                commands: ['customSortData'],
              },
              {
                type: 'separator',
              },
              {
                commands: ['setFilterData'],
              },
              {
                direction: 'vertical',
                commands: ['clearFilterData', 'reapplyFilterData'],
              },
            ],
          },
        },
      ],
      visibleWhen: '!IsInTableSheetDesignMode',
    },
   
  ],
  contextMenu: [
    
    'separator',
    'deleteDialog',
    'customInsertColumnsLeft',  'customInsertColumnsRight',
 
    // 'gc.spread.contextMenu.insertColumns',
    'gc.spread.contextMenu.deleteColumns',
    // 'gc.spread.contextMenu.insertRows',
    'gc.spread.contextMenu.deleteRows',
    'gc.spread.contextMenu.clearContents',
   
  ],
  // fileMenu: 'fileMenuButton',
  fileMenu: null,
  sidePanels: [
    {
      position: 'top',
      allowResize: true,
      command: 'formulaBarPanel',
      uiTemplate: 'formulaBarTemplate',
    },
    {
      position: 'right',
      width: '315px',
      command: 'fieldListTreePanel',
      uiTemplate: 'filedListTemplate',
    },
    {
      position: 'bottom',
      command: 'statusBarPanel',
      uiTemplate: 'statusBarPanelTemplate',
    },
    {
      position: 'full',
      command: 'fileMenuPanel',
      uiTemplate: 'fileMenuPanelTemplate',
    },
    {
      position: 'right',
      width: '315px',
      command: 'shapePanel',
      uiTemplate: 'shapeTemplate',
    },
    {
      position: 'right',
      width: '315px',
      command: 'pictureAltTextPanel',
      uiTemplate: 'altTextTemplate',
      showCloseButton: true,
    },
    {
      position: 'right',
      width: '315px',
      command: 'shapeAltTextPanel',
      uiTemplate: 'altTextTemplate',
      showCloseButton: true,
    },
    {
      position: 'right',
      width: '315px',
      command: 'pivotTablePanel',
      uiTemplate: 'insertPivotTableDialogTemplate',
      classList: ['gc-designer-pivot-table-panel'],
      showCloseButton: true,
    },
    {
      position: 'right',
      width: '315px',
      command: 'tableSheetPanel',
      uiTemplate: 'tableSheetPanelTemplate',
      classList: ['gc-designer-table-sheet-panel'],
      showCloseButton: true,
      
    },
    {
      position: 'right',
      width: '315px',
      command: 'selectionPane',
      uiTemplate: 'selectionPane',
      classList: ['gc-designer-selection-pane'],
      showCloseButton: true,
    },
  ],
  commandMap: {
    handleSelectRows: {
      text: "Select Row",
      bigButton: true,
      direction: "vertical",
      iconClass: "selectRows",
      commandName: "handleSelectRows",
    },
    handleAddColumn: {
      text: "Insert",
      bigButton: 'true',
      iconClass: "insertColumn",
      commandName: "handleAddColumn",
    },
    handleDeleteColumn: {
      text: "Delete",
      bigButton: 'true',
      iconClass: "deleteColumn",
      commandName: "handleDeleteColumn",
      enableContext:'TableSelected'
    },
    handleGroupBy: {
      text: "Group By",
      bigButton: 'true',
      iconClass: "groupBy",
      commandName: "handleGroupBy",
    },
    handleProcessingStep: {
      text: "Processing Step List",
      bigButton: 'true',
      iconClass: "processingStep",
      commandName: "handleProcessingStep",
    },
    handleInfo: {
      text: "Info",
      bigButton: 'true',
      iconClass: "info",
      commandName: "handleInfo",
    },
    customInsertColumnsLeft: {
      text: 'Insert Column left',
      commandName: 'customInsertColumnsLeft',
      visibleContext:
        '!TabStripSelected && !ClickRowHeader && !PivotTableSelected',
      enableContext: 'TableSelected',
      execute: (args) => {
        handleCustomInsertColumn(args,"LEFT");

        }
    },
    customInsertColumnsRight: {
      text: 'Insert Columns Right',
      commandName: 'customInsertColumnsRight',
      visibleContext:
        '!TabStripSelected && !ClickRowHeader && !PivotTableSelected',
      enableContext: 'TableSelected',
      execute: (args) => {
        handleCustomInsertColumn(args,"RIGHT");

        }
          
      },
 
    // customInsertRowAbove: {
    //   text: 'Insert Rows Above',
    //   commandName: 'gc.spread.contextMenu.insertRows',
    //   visibleContext:
    //     '!TabStripSelected && !ClickColHeader && !PivotTableSelected',
    //   enableContext: '!isProtected',
    // },
    // customInsertRowBelow: {
    //   text: 'Insert Rows Below',
    //   commandName: 'customInsertRowBelow',
    //   visibleContext:
    //     '!TabStripSelected && !ClickColHeader && !PivotTableSelected',
    //   enableContext: '!isProtected',
    //   execute: (args) => {
    //     const activeSheet = args.Spread.getActiveSheet();
    //     console.log(activeSheet.table.findB)
    //   },
    // },
  
  },
};
